@@ -40,8 +40,12 @@ extern GList* collect_full_irq_list();
 extern void parse_proc_stat(void);
 extern void set_interrupt_count(int number, uint64_t count);
 extern void set_msi_interrupt_numa(int number);
+extern void init_irq_class_and_type(char *savedline, struct irq_info *info, int irq);
+extern int proc_irq_hotplug(char *line, int irq, struct irq_info **pinfo);
+extern void clear_no_existing_irqs(void);
 
 extern GList *rebalance_irq_list;
+extern void force_rebalance_irq(struct irq_info *info, void *data __attribute__((unused)));
 
 void update_migration_status(void);
 void dump_workloads(void);
@@ -52,7 +56,6 @@ void dump_tree(void);
 void activate_mappings(void);
 void clear_cpu_tree(void);
 void free_cpu_topo(gpointer data);
-
 /*===================NEW BALANCER FUNCTIONS============================*/
 
 /*
@@ -106,8 +109,6 @@ extern struct irq_info *get_irq_info(int irq);
 extern void migrate_irq(GList **from, GList **to, struct irq_info *info);
 extern void free_cl_opts(void);
 extern void add_cl_banned_module(char *modname);
-extern void add_banned_irq(int irq);
-extern void remove_one_irq_from_db(int irq);
 #define irq_numa_node(irq) ((irq)->numa_node)
 
 
