@@ -34,7 +34,8 @@
 /*
  * IRQ Internal tracking flags
  */
-#define IRQ_FLAG_BANNED	1
+#define IRQ_FLAG_BANNED                 (1ULL << 0)
+#define IRQ_FLAG_AFFINITY_UNMANAGED     (1ULL << 1)
 
 enum obj_type_e {
 	OBJ_TYPE_CPU,
